



if not exist %PREFIX%\\Library\\include\\yajl\\yajl_common.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\yajl_s.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\yajl.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
